aboutsummaryrefslogtreecommitdiffstats
path: root/pkg/ipc
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/ipc')
-rw-r--r--pkg/ipc/ipc.go25
1 files changed, 13 insertions, 12 deletions
diff --git a/pkg/ipc/ipc.go b/pkg/ipc/ipc.go
index 11e73835b..5ae502e5d 100644
--- a/pkg/ipc/ipc.go
+++ b/pkg/ipc/ipc.go
@@ -28,18 +28,19 @@ type EnvFlags uint64
// Note: New / changed flags should be added to parse_env_flags in executor.cc.
const (
- FlagDebug EnvFlags = 1 << iota // debug output from executor
- FlagSignal // collect feedback signals (coverage)
- FlagSandboxSetuid // impersonate nobody user
- FlagSandboxNamespace // use namespaces for sandboxing
- FlagSandboxAndroid // use Android sandboxing for the untrusted_app domain
- FlagExtraCover // collect extra coverage
- FlagEnableTun // setup and use /dev/tun for packet injection
- FlagEnableNetDev // setup more network devices for testing
- FlagEnableNetReset // reset network namespace between programs
- FlagEnableCgroups // setup cgroups for testing
- FlagEnableCloseFds // close fds after each program
- FlagEnableDevlinkPCI // setup devlink PCI device
+ FlagDebug EnvFlags = 1 << iota // debug output from executor
+ FlagSignal // collect feedback signals (coverage)
+ FlagSandboxSetuid // impersonate nobody user
+ FlagSandboxNamespace // use namespaces for sandboxing
+ FlagSandboxAndroid // use Android sandboxing for the untrusted_app domain
+ FlagExtraCover // collect extra coverage
+ FlagEnableTun // setup and use /dev/tun for packet injection
+ FlagEnableNetDev // setup more network devices for testing
+ FlagEnableNetReset // reset network namespace between programs
+ FlagEnableCgroups // setup cgroups for testing
+ FlagEnableCloseFds // close fds after each program
+ FlagEnableDevlinkPCI // setup devlink PCI device
+ FlagEnableVhciInjection // setup and use /dev/vhci for hci packet injection
)
// Per-exec flags for ExecOpts.Flags.